@@ -7,7 +7,7 @@ use CLDR::Number;
 
 use Mojolicious::Plugin::I18NUtils::Locale;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub register {
     my ($self, $app, $config) = @_;
@@ -262,7 +262,7 @@ Mojolicious::Plugin::I18NUtils - provide some helper functions for I18N
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -362,9 +362,9 @@ will return
 
 will return
 
-  ٢٬٠٠٠
-  2.000
-  2,000
+  +٢٬٠٠٠
+  2.000+
+  2,000+
 
 =head1 METHODS
 
